@@ -240,6 +240,11 @@ class KeytotextTrainer:
         pass
 
     def from_pretrained(self, model_name="t5-base"):
+        """
+        Download Model from HF hub
+        :param model_name: T5
+        :return: Download the model and tokenizer
+        """
         self.tokenizer = T5Tokenizer.from_pretrained(f"{model_name}")
         self.model = T5ForConditionalGeneration.from_pretrained(
             f"{model_name}", return_dict=True
@@ -258,7 +263,7 @@ class KeytotextTrainer:
             test_split=0.1,
     ):
         """
-        trains T5/MT5 model on custom dataset
+        trains T5 model on custom dataset
         Args:
             data_df (pd.DataFrame): training datarame. Dataframe must have 2 column --> "keywords" and "text"
             source_max_token_len (int, optional): max token length of source text. Defaults to 512.
@@ -339,6 +344,11 @@ class KeytotextTrainer:
             self,
             model_dir="outputs"
     ):
+        """
+        Save model to dir
+        :param model_dir:
+        :return: model is saved
+        """
         path = f"{model_dir}/keytotext-epoch-{self.max_epoch}"
         self.tokenizer.save_pretrained(path)
         self.model.save_pretrained(path)
@@ -362,7 +372,7 @@ class KeytotextTrainer:
         """
         generates prediction for K2T model
         Args:
-            Keywords (list): any text for generating predictions
+            Keywords (list): any keywords for generating predictions
             max_length (int, optional): max token length of prediction. Defaults to 512.
             num_return_sequences (int, optional): number of predictions to be returned. Defaults to 1.
             num_beams (int, optional): number of beams. Defaults to 2.
@@ -376,7 +386,7 @@ class KeytotextTrainer:
             clean_up_tokenization_spaces (bool, optional): Defaults to True.
             use_gpu: Defaults to True.
         Returns:
-            list[str]: returns predictions
+            str: returns predictions
         """
         if use_gpu:
             if torch.cuda.is_available():
